@@ -453,31 +453,31 @@ yeccpars2(Other, _, _, _, _, _, _) ->
 
 -dialyzer({nowarn_function, yeccpars2_0/7}).
 -compile({nowarn_unused_function,  yeccpars2_0/7}).
-yeccpars2_0(S, avp_types, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'avp_types', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 4, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, avp_vendor_id, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'avp_vendor_id', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 5, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, codecs, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'codecs', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 6, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, custom_types, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'custom_types', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 7, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, define, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'define', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 8, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, enum, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'enum', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 9, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, grouped, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'grouped', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 10, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, id, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'id', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 11, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, inherits, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'inherits', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 12, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, messages, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'messages', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 13, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, name, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'name', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 14, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, prefix, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'prefix', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 15, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, vendor, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'vendor', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 16, Ss, Stack, T, Ts, Tzr);
 yeccpars2_0(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_0_(Stack),
@@ -491,31 +491,31 @@ yeccpars2_1(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_2/7}).
 -compile({nowarn_unused_function,  yeccpars2_2/7}).
-yeccpars2_2(S, avp_types, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'avp_types', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 4, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, avp_vendor_id, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'avp_vendor_id', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 5, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, codecs, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'codecs', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 6, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, custom_types, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'custom_types', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 7, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, define, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'define', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 8, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, enum, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'enum', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 9, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, grouped, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'grouped', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 10, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, id, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'id', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 11, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, inherits, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'inherits', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 12, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, messages, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'messages', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 13, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, name, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'name', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 14, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, prefix, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'prefix', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 15, Ss, Stack, T, Ts, Tzr);
-yeccpars2_2(S, vendor, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_2(S, 'vendor', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 16, Ss, Stack, T, Ts, Tzr);
 yeccpars2_2(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_2_(Stack),
@@ -530,7 +530,7 @@ yeccpars2_3(_, _, _, _, T, _, _) ->
 
 -dialyzer({nowarn_function, yeccpars2_4/7}).
 -compile({nowarn_unused_function,  yeccpars2_4/7}).
-yeccpars2_4(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_4(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_4(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_4_(Stack),
@@ -538,14 +538,14 @@ yeccpars2_4(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_5/7}).
 -compile({nowarn_unused_function,  yeccpars2_5/7}).
-yeccpars2_5(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_5(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 119, Ss, Stack, T, Ts, Tzr);
 yeccpars2_5(_, _, _, _, T, _, _) ->
  yeccerror(T).
 
 -dialyzer({nowarn_function, yeccpars2_6/7}).
 -compile({nowarn_unused_function,  yeccpars2_6/7}).
-yeccpars2_6(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_6(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_6(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -558,7 +558,7 @@ yeccpars2_6(_, _, _, _, T, _, _) ->
 
 -dialyzer({nowarn_function, yeccpars2_10/7}).
 -compile({nowarn_unused_function,  yeccpars2_10/7}).
-yeccpars2_10(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_10(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_10(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_10_(Stack),
@@ -566,7 +566,7 @@ yeccpars2_10(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_11/7}).
 -compile({nowarn_unused_function,  yeccpars2_11/7}).
-yeccpars2_11(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_11(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 88, Ss, Stack, T, Ts, Tzr);
 yeccpars2_11(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -577,7 +577,7 @@ yeccpars2_11(_, _, _, _, T, _, _) ->
 -compile({nowarn_unused_function,  yeccpars2_13/7}).
 yeccpars2_13(S, 'answer-message', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 26, Ss, Stack, T, Ts, Tzr);
-yeccpars2_13(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_13(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_13(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_13_(Stack),
@@ -589,7 +589,7 @@ yeccpars2_13(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_16/7}).
 -compile({nowarn_unused_function,  yeccpars2_16/7}).
-yeccpars2_16(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_16(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 17, Ss, Stack, T, Ts, Tzr);
 yeccpars2_16(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -647,7 +647,7 @@ yeccpars2_24(_, _, _, _, T, _, _) ->
 -compile({nowarn_unused_function,  yeccpars2_25/7}).
 yeccpars2_25(S, 'answer-message', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 26, Ss, Stack, T, Ts, Tzr);
-yeccpars2_25(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_25(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_25(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_25_(Stack),
@@ -705,7 +705,7 @@ yeccpars2_32(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_33/7}).
 -compile({nowarn_unused_function,  yeccpars2_33/7}).
-yeccpars2_33(S, code, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_33(S, 'code', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 34, Ss, Stack, T, Ts, Tzr);
 yeccpars2_33(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -760,7 +760,7 @@ yeccpars2_40(S, '<', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 46, Ss, Stack, T, Ts, Tzr);
 yeccpars2_40(S, '[', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 47, Ss, Stack, T, Ts, Tzr);
-yeccpars2_40(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_40(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 48, Ss, Stack, T, Ts, Tzr);
 yeccpars2_40(S, '{', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 49, Ss, Stack, T, Ts, Tzr);
@@ -800,7 +800,7 @@ yeccpars2_44(S, '<', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 46, Ss, Stack, T, Ts, Tzr);
 yeccpars2_44(S, '[', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 47, Ss, Stack, T, Ts, Tzr);
-yeccpars2_44(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_44(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 48, Ss, Stack, T, Ts, Tzr);
 yeccpars2_44(S, '{', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 49, Ss, Stack, T, Ts, Tzr);
@@ -810,7 +810,7 @@ yeccpars2_44(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_45/7}).
 -compile({nowarn_unused_function,  yeccpars2_45/7}).
-yeccpars2_45(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_45(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 61, Ss, Stack, T, Ts, Tzr);
 yeccpars2_45(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_45_(Stack),
@@ -822,7 +822,7 @@ yeccpars2_45(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 -compile({nowarn_unused_function,  yeccpars2_47/7}).
 yeccpars2_47(S, 'AVP', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 53, Ss, Stack, T, Ts, Tzr);
-yeccpars2_47(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_47(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_47(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -870,7 +870,7 @@ yeccpars2_54(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_55/7}).
 -compile({nowarn_unused_function,  yeccpars2_55/7}).
-yeccpars2_55(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_55(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 56, Ss, Stack, T, Ts, Tzr);
 yeccpars2_55(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_|Nss] = Ss,
@@ -955,7 +955,7 @@ yeccpars2_66(S, '<', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 46, Ss, Stack, T, Ts, Tzr);
 yeccpars2_66(S, '[', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 47, Ss, Stack, T, Ts, Tzr);
-yeccpars2_66(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_66(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 48, Ss, Stack, T, Ts, Tzr);
 yeccpars2_66(S, '{', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 49, Ss, Stack, T, Ts, Tzr);
@@ -974,7 +974,7 @@ yeccpars2_68(_, _, _, _, T, _, _) ->
 
 -dialyzer({nowarn_function, yeccpars2_69/7}).
 -compile({nowarn_unused_function,  yeccpars2_69/7}).
-yeccpars2_69(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_69(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 71, Ss, Stack, T, Ts, Tzr);
 yeccpars2_69(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -995,7 +995,7 @@ yeccpars2_71(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_72/7}).
 -compile({nowarn_unused_function,  yeccpars2_72/7}).
-yeccpars2_72(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_72(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 79, Ss, Stack, T, Ts, Tzr);
 yeccpars2_72(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_72_(Stack),
@@ -1066,7 +1066,7 @@ yeccpars2_81(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_82/7}).
 -compile({nowarn_unused_function,  yeccpars2_82/7}).
-yeccpars2_82(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_82(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_82(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_82_(Stack),
@@ -1086,7 +1086,7 @@ yeccpars2_84(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_85/7}).
 -compile({nowarn_unused_function,  yeccpars2_85/7}).
-yeccpars2_85(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_85(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_85(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_85_(Stack),
@@ -1129,7 +1129,7 @@ yeccpars2_90(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_91/7}).
 -compile({nowarn_unused_function,  yeccpars2_91/7}).
-yeccpars2_91(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_91(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_91(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_91_(Stack),
@@ -1157,7 +1157,7 @@ yeccpars2_94(S, '<', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 46, Ss, Stack, T, Ts, Tzr);
 yeccpars2_94(S, '[', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 47, Ss, Stack, T, Ts, Tzr);
-yeccpars2_94(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_94(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 48, Ss, Stack, T, Ts, Tzr);
 yeccpars2_94(S, '{', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 49, Ss, Stack, T, Ts, Tzr);
@@ -1203,14 +1203,14 @@ yeccpars2_99(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_100/7}).
 -compile({nowarn_unused_function,  yeccpars2_100/7}).
-yeccpars2_100(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_100(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 102, Ss, Stack, T, Ts, Tzr);
 yeccpars2_100(_, _, _, _, T, _, _) ->
  yeccerror(T).
 
 -dialyzer({nowarn_function, yeccpars2_101/7}).
 -compile({nowarn_unused_function,  yeccpars2_101/7}).
-yeccpars2_101(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_101(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 104, Ss, Stack, T, Ts, Tzr);
 yeccpars2_101(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_101_(Stack),
@@ -1251,7 +1251,7 @@ yeccpars2_106(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_107/7}).
 -compile({nowarn_unused_function,  yeccpars2_107/7}).
-yeccpars2_107(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_107(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_107(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_107_(Stack),
@@ -1259,7 +1259,7 @@ yeccpars2_107(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_108/7}).
 -compile({nowarn_unused_function,  yeccpars2_108/7}).
-yeccpars2_108(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_108(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 112, Ss, Stack, T, Ts, Tzr);
 yeccpars2_108(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -1273,7 +1273,7 @@ yeccpars2_109(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_110/7}).
 -compile({nowarn_unused_function,  yeccpars2_110/7}).
-yeccpars2_110(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_110(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_110(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_110_(Stack),
@@ -1295,7 +1295,7 @@ yeccpars2_112(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_113/7}).
 -compile({nowarn_unused_function,  yeccpars2_113/7}).
-yeccpars2_113(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_113(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_113(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_113_(Stack),
@@ -1310,7 +1310,7 @@ yeccpars2_114(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_115/7}).
 -compile({nowarn_unused_function,  yeccpars2_115/7}).
-yeccpars2_115(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_115(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_115(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_115_(Stack),
@@ -1325,7 +1325,7 @@ yeccpars2_116(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_117/7}).
 -compile({nowarn_unused_function,  yeccpars2_117/7}).
-yeccpars2_117(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_117(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_117(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_117_(Stack),
@@ -1340,7 +1340,7 @@ yeccpars2_118(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_119/7}).
 -compile({nowarn_unused_function,  yeccpars2_119/7}).
-yeccpars2_119(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_119(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_119(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_119_(Stack),
@@ -1355,7 +1355,7 @@ yeccpars2_120(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_121/7}).
 -compile({nowarn_unused_function,  yeccpars2_121/7}).
-yeccpars2_121(S, number, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_121(S, 'number', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 125, Ss, Stack, T, Ts, Tzr);
 yeccpars2_121(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -1369,7 +1369,7 @@ yeccpars2_122(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_123/7}).
 -compile({nowarn_unused_function,  yeccpars2_123/7}).
-yeccpars2_123(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_123(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_123(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_123_(Stack),
@@ -1394,7 +1394,7 @@ yeccpars2_126(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 -compile({nowarn_unused_function,  yeccpars2_127/7}).
 yeccpars2_127(S, '-', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 130, Ss, Stack, T, Ts, Tzr);
-yeccpars2_127(S, word, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_127(S, 'word', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
 yeccpars2_127(_, _, _, _, T, _, _) ->
  yeccerror(T).
